@@ -1,5 +1,5 @@
 import logging
-from typing import Tuple
+from typing import Tuple, Dict
 
 import tensorflow as tf
 from tensorflow.keras import Model, Input
@@ -11,8 +11,16 @@ def is_custom_layers(model: Model) -> bool:
     return any(is_custom_layer(layer) for layer in model.layers)
 
 
+def should_replace_layers(model: Model, layer_replacement_dict: Dict[str, Layer]) -> bool:
+    if layer_replacement_dict:
+        for layer in model.layers:
+            if layer.name in layer_replacement_dict:
+                return True
+    return False
+
+
 def is_custom_layer(layer: Layer) -> bool:
-    return not layer.__module__.startswith("tensorflow")
+    return not layer.__module__.startswith("tensorflow") or layer.__class__.__name__ == 'Functional'
 
 
 def convert_subclassed_to_functional(model: Model, input_tensor_shape: Tuple[int, ...]) -> Functional:
